# PCCM
Python C++ Code Manager

[![Build Status](https://github.com/FindDefinition/PCCM/workflows/build/badge.svg)](https://github.com/FindDefinition/PCCM/actions?query=workflow%3Abuild)

Only pccm 0.1.x support python 3.5, pccm >= 0.2.0 require python >= 3.6.

## Docs

see [introduction ppt](docs/PCCM_intro.pptx) or [pdf](docs/PCCM_intro.pdf)